==> kadaster-gds2-1.2-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstopvragenresultaat/v20130701/BestandenlijstOpvragenResultaatType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragenresultaat.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragenresultaat.afgifte.v20130701.BestandenLijstType;
import nl.kadaster.schemas.generiek_extern.procesresultaat.v20110922.ProcesVerwerking;


/**
 * De opgevraagde bestandenlijst met (niet grote)
 * 				bestanden inclusief afgifte gegevens. De lijst bevat die afgiftes
 * 				die voldoen aan de gebruikte selectiegegevens. Indien er geen
 * 				afgiftes voldoen aan deze selectie gegevens, dan is er geen
 * 				bestandenlijst aanwezig in het resultaat.
 * 
 * <p>Java class for BestandenlijstOpvragenResultaatType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BestandenlijstOpvragenResultaatType">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922}ProcesVerwerking"/>
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstopvragenresultaat/afgifte/v20130701}BestandenLijst" minOccurs="0"/>
 *         &lt;element name="meerAfgiftesbeschikbaar" minOccurs="0">
 *           &lt;simpleType>
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *               &lt;length value="1"/>
 *             &lt;/restriction>
 *           &lt;/simpleType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BestandenlijstOpvragenResultaatType", propOrder = {
    "procesVerwerking",
    "bestandenLijst",
    "meerAfgiftesbeschikbaar"
})
public class BestandenlijstOpvragenResultaatType {

    @XmlElement(name = "ProcesVerwerking", namespace = "http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", required = true)
    protected ProcesVerwerking procesVerwerking;
    @XmlElement(name = "BestandenLijst", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstopvragenresultaat/afgifte/v20130701")
    protected BestandenLijstType bestandenLijst;
    @XmlElement(defaultValue = "J")
    protected String meerAfgiftesbeschikbaar;

    /**
     * Gets the value of the procesVerwerking property.
     * 
     * @return
     *     possible object is
     *     {@link ProcesVerwerking }
     *     
     */
    public ProcesVerwerking getProcesVerwerking() {
        return procesVerwerking;
    }

    /**
     * Sets the value of the procesVerwerking property.
     * 
     * @param value
     *     allowed object is
     *     {@link ProcesVerwerking }
     *     
     */
    public void setProcesVerwerking(ProcesVerwerking value) {
        this.procesVerwerking = value;
    }

    /**
     * Gets the value of the bestandenLijst property.
     * 
     * @return
     *     possible object is
     *     {@link BestandenLijstType }
     *     
     */
    public BestandenLijstType getBestandenLijst() {
        return bestandenLijst;
    }

    /**
     * Sets the value of the bestandenLijst property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandenLijstType }
     *     
     */
    public void setBestandenLijst(BestandenLijstType value) {
        this.bestandenLijst = value;
    }

    /**
     * Gets the value of the meerAfgiftesbeschikbaar property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMeerAfgiftesbeschikbaar() {
        return meerAfgiftesbeschikbaar;
    }

    /**
     * Sets the value of the meerAfgiftesbeschikbaar property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMeerAfgiftesbeschikbaar(String value) {
        this.meerAfgiftesbeschikbaar = value;
    }

}

==> kadaster-gds2-2.3-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstopvragenresultaat/v20130701/BestandenlijstOpvragenResultaatType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragenresultaat.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragenresultaat.afgifte.v20130701.BestandenLijstType;
import nl.kadaster.schemas.generiek_extern.procesresultaat.v20110922.ProcesVerwerking;


/**
 * De opgevraagde bestandenlijst met (niet grote)
 * 				bestanden inclusief afgifte gegevens. De lijst bevat die afgiftes
 * 				die voldoen aan de gebruikte selectiegegevens. Indien er geen
 * 				afgiftes voldoen aan deze selectie gegevens, dan is er geen
 * 				bestandenlijst aanwezig in het resultaat.
 * 
 * &lt;p&gt;Java class for BestandenlijstOpvragenResultaatType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="BestandenlijstOpvragenResultaatType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922}ProcesVerwerking"/&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstopvragenresultaat/afgifte/v20130701}BestandenLijst" minOccurs="0"/&amp;gt;
 *         &amp;lt;element name="meerAfgiftesbeschikbaar" minOccurs="0"&amp;gt;
 *           &amp;lt;simpleType&amp;gt;
 *             &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&amp;gt;
 *               &amp;lt;length value="1"/&amp;gt;
 *             &amp;lt;/restriction&amp;gt;
 *           &amp;lt;/simpleType&amp;gt;
 *         &amp;lt;/element&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BestandenlijstOpvragenResultaatType", propOrder = {
    "procesVerwerking",
    "bestandenLijst",
    "meerAfgiftesbeschikbaar"
})
public class BestandenlijstOpvragenResultaatType {

    @XmlElement(name = "ProcesVerwerking", namespace = "http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", required = true)
    protected ProcesVerwerking procesVerwerking;
    @XmlElement(name = "BestandenLijst", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstopvragenresultaat/afgifte/v20130701")
    protected BestandenLijstType bestandenLijst;
    @XmlElement(defaultValue = "J")
    protected String meerAfgiftesbeschikbaar;

    /**
     * Gets the value of the procesVerwerking property.
     * 
     * @return
     *     possible object is
     *     {@link ProcesVerwerking }
     *     
     */
    public ProcesVerwerking getProcesVerwerking() {
        return procesVerwerking;
    }

    /**
     * Sets the value of the procesVerwerking property.
     * 
     * @param value
     *     allowed object is
     *     {@link ProcesVerwerking }
     *     
     */
    public void setProcesVerwerking(ProcesVerwerking value) {
        this.procesVerwerking = value;
    }

    /**
     * Gets the value of the bestandenLijst property.
     * 
     * @return
     *     possible object is
     *     {@link BestandenLijstType }
     *     
     */
    public BestandenLijstType getBestandenLijst() {
        return bestandenLijst;
    }

    /**
     * Sets the value of the bestandenLijst property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandenLijstType }
     *     
     */
    public void setBestandenLijst(BestandenLijstType value) {
        this.bestandenLijst = value;
    }

    /**
     * Gets the value of the meerAfgiftesbeschikbaar property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMeerAfgiftesbeschikbaar() {
        return meerAfgiftesbeschikbaar;
    }

    /**
     * Sets the value of the meerAfgiftesbeschikbaar property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMeerAfgiftesbeschikbaar(String value) {
        this.meerAfgiftesbeschikbaar = value;
    }

}
